@@ -10,6 +10,7 @@ package main
 
 import (
 	"context"
+	"fmt"
 	"net"
 	"net/http"
 	"time"
@@ -132,6 +133,22 @@ func NewDevice(desc UsbDeviceDesc) (*Device, error) {
 	// Advertise Web service. Assume it always exists
 	dnssdServices.Add(DNSSdSvcInfo{Type: "_http._tcp", Port: dev.State.HTTPPort})
 
+	// Advertise service with the following parameters:
+	//   Instance: "BBPP", where BB and PP are bus and port numbers in hex
+	//   Type:     "_ipp-usb._tcp"
+	//
+	// The purpose of this advertising is to help legacy drivers to
+	// easily check for devices, handled by ipp-usb
+	//
+	// See the following for details:
+	//     https://github.com/OpenPrinting/ipp-usb/issues/28
+	dnssdServices.Add(DNSSdSvcInfo{
+		Instance: fmt.Sprintf("%.2X%.2x", desc.Bus, info.PortNum),
+		Type:     "_ipp-usb._tcp",
+		Port:     dev.State.HTTPPort,
+		Loopback: true,
+	})
+
 	// Enable handling incoming requests
 	dev.UsbTransport.SetDeadline(time.Time{})
 	dev.HTTPProxy.Enable()
