@@ -49,14 +49,31 @@ func IppService(log *LogMessage, services *DNSSdServices,
 	attrs := newIppDecoder(msg)
 	ippinfo, ippScv := attrs.decode(usbinfo)
 
-	// Probe for fax support
-	uri = fmt.Sprintf("http://localhost:%d/ipp/faxout", port)
-	if _, err2 := ippGetPrinterAttributes(log, c, uri); err2 == nil {
-		log.Debug(' ', "IPP FaxOut service detected")
+	// Check for fax support
+	canFax := false
+	if usbinfo.BasicCaps&UsbIppBasicCapsFax != 0 {
+		// Note, as device lists Fax on its basic capabilities,
+		// this probe most likely is not needed, but as the
+		// ipp-usb version 0.9.19 and earlier used to guess
+		// for fax support based on the /ipp/faxout probe,
+		// not on device capabilities, lets leave it here
+		// for now, just in case. Firmwares in general are
+		// too buggy, I can't trust them :-(
+		uri = fmt.Sprintf("http://localhost:%d/ipp/faxout", port)
+		if _, err2 := ippGetPrinterAttributes(log, c, uri); err2 == nil {
+			canFax = true
+			log.Debug(' ', "IPP FaxOut service detected")
+		} else {
+			log.Error('!', "IPP FaxOut probe failed: %s", err2)
+		}
+	} else {
+		log.Debug(' ', "IPP FaxOut service not in capabilities")
+	}
+
+	if canFax {
 		ippScv.Txt.Add("Fax", "T")
 		ippScv.Txt.Add("rfo", "ipp/faxout")
 	} else {
-		log.Debug(' ', "IPP FaxOut service not present")
 		ippScv.Txt.Add("Fax", "F")
 	}
 
@@ -98,8 +115,24 @@ func ippGetPrinterAttributes(log *LogMessage, c *http.Client, uri string) (
 		goipp.TagLanguage, goipp.String("en-US")))
 	msg.Operation.Add(goipp.MakeAttribute("printer-uri",
 		goipp.TagURI, goipp.String(uri)))
-	msg.Operation.Add(goipp.MakeAttribute("requested-attributes",
-		goipp.TagKeyword, goipp.String("all")))
+
+	rq := goipp.Attribute{Name: "requested-attributes"}
+	rq.Values.Add(goipp.TagKeyword, goipp.String("color-supported"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("document-format-supported"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("media-size-supported"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("mopria-certified"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-device-id"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-dns-sd-name"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-icons"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-info"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-kind"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-location"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-make-and-model"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-more-info"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("printer-uuid"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("sides-supported"))
+	rq.Values.Add(goipp.TagKeyword, goipp.String("urf-supported"))
+	msg.Operation.Add(rq)
 
 	log.Add(LogTraceIPP, '>', "IPP request:").
 		IppRequest(LogTraceIPP, '>', msg).
