@@ -9,6 +9,7 @@
 package main
 
 import (
+	"encoding/binary"
 	"errors"
 	"sync"
 	"sync/atomic"
@@ -472,6 +473,7 @@ func (devhandle *UsbDevHandle) UsbDeviceInfo() (UsbDeviceInfo, error) {
 	// Decode device descriptor
 	info.Vendor = uint16(c_desc.idVendor)
 	info.Product = uint16(c_desc.idProduct)
+	info.BasicCaps = devhandle.usbIppBasicCaps()
 
 	buf := make([]byte, 256)
 
@@ -504,6 +506,54 @@ func (devhandle *UsbDevHandle) UsbDeviceInfo() (UsbDeviceInfo, error) {
 	return info, nil
 }
 
+// usbIppBasicCaps reads and decodes printer's
+// Class-specific Device Info Descriptor to obtain device
+// capabilities
+//
+// See IPP USB specification, section 4.3 for details
+//
+// This function never fails. In a case of errors, it fall backs
+// to the reasonable default
+func (devhandle *UsbDevHandle) usbIppBasicCaps() (caps UsbIppBasicCaps) {
+	// Safe default
+	caps = UsbIppBasicCapsPrint |
+		UsbIppBasicCapsScan |
+		UsbIppBasicCapsFax |
+		UsbIppBasicCapsAnyHTTP
+
+	// Buffer length
+	const bufLen = 256
+
+	// Obtain class-specific Device Info Descriptor
+	// See IPP USB specification, section 4.3 for details
+	buf := make([]byte, bufLen)
+	rc := C.libusb_get_descriptor(
+		(*C.libusb_device_handle)(devhandle),
+		0x21, 0,
+		(*C.uchar)(unsafe.Pointer(&buf[0])),
+		bufLen)
+
+	if rc < 0 {
+		// Some devices doesn't properly return class-specific
+		// device descriptor, so ignore an error
+		return
+	}
+
+	if rc < 10 {
+		// Malformed response, fall back to default
+		return
+	}
+
+	// Decode basic capabilities bits
+	bits := binary.LittleEndian.Uint16(buf[6:8])
+	if bits == 0 {
+		// Paranoia. If no caps, return default
+		return
+	}
+
+	return UsbIppBasicCaps(bits)
+}
+
 // OpenUsbInterface opens an interface
 func (devhandle *UsbDevHandle) OpenUsbInterface(addr UsbIfAddr) (
 	*UsbInterface, error) {
